==> trade-center-api-2.3.75-sources.jar: cn/com/duiba/order/center/api/paramquery/OrderMonthQueryParams.java <==
package cn.com.duiba.order.center.api.paramquery;


import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 异常订单查询类
 */
public class OrderMonthQueryParams implements Serializable{

    private static final long serialVersionUID = -71190659491247935L;




    private Date startTime;

    private Date endTime;


    private Integer offset; // 分页偏移量

    private Integer pageSize; // 每页个数
    private String tableName;
    private List<Long> appItemIds;
    private Long appId;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public List<Long> getAppItemIds() {
        return appItemIds;
    }

    public void setAppItemIds(List<Long> appItemIds) {
        this.appItemIds = appItemIds;
    }

    public String getTableName() {
        return tableName;
    }

    public void setTableName(String tableName) {
        this.tableName = tableName;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }


    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }


    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
}

==> trade-center-api-2.4.24-20220614.034815-1-sources.jar: cn/com/duiba/order/center/api/paramquery/OrderMonthQueryParams.java <==
package cn.com.duiba.order.center.api.paramquery;


import cn.com.duiba.order.center.api.constant.FlowStageConstant;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 异常订单查询类
 */
public class OrderMonthQueryParams implements Serializable{

    private static final long serialVersionUID = -71190659491247935L;




    private Date startTime;

    private Date endTime;


    private Integer offset; // 分页偏移量

    private Integer pageSize; // 每页个数
    private String tableName;
    private List<Long> appItemIds;

    private Long itemId;
    private List<Long> itemIds;

    private String type;

    private List<Long> appIds;

    private Long appId;

    private List<String> flowStageList;

    public List<String> getFlowStageList() {
        return flowStageList;
    }

    public void setFlowStageList(List<String> flowStageList) {
        this.flowStageList = flowStageList;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public List<Long> getItemIds() {
        return itemIds;
    }

    public void setItemIds(List<Long> itemIds) {
        this.itemIds = itemIds;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public List<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(List<Long> appIds) {
        this.appIds = appIds;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }
    public List<Long> getAppItemIds() {
        return appItemIds;
    }

    public void setAppItemIds(List<Long> appItemIds) {
        this.appItemIds = appItemIds;
    }

    public String getTableName() {
        return tableName;
    }

    public void setTableName(String tableName) {
        this.tableName = tableName;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }


    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }


    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
}
